@@ -34,19 +34,18 @@
 //           Skomakerveien 33
 //           3185 Skoppum, NORWAY
 
-// Add some helpfull words here. (These are some words, hope they are
-// helpful)
+// Add some helpfull words here.
 
 #ifndef LIBTORRENT_CONNECTION_MANAGER_H
 #define LIBTORRENT_CONNECTION_MANAGER_H
 
+#include <functional>
 #include <list>
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
 #include <sys/socket.h>
-#include <functional>
 #include <torrent/common.h>
 
 namespace torrent {
@@ -168,6 +167,15 @@ public:
   // For internal usage.
   Listen*             listen()            { return m_listen; }
 
+  bool                is_block_ipv4() const  { return m_block_ipv4; }
+  void                set_block_ipv4(bool v) { m_block_ipv4 = v; }
+
+  bool                is_block_ipv6() const  { return m_block_ipv6; }
+  void                set_block_ipv6(bool v) { m_block_ipv6 = v; }
+
+  bool                is_prefer_ipv6() const  { return m_prefer_ipv6; }
+  void                set_prefer_ipv6(bool v) { m_prefer_ipv6 = v; }
+
 private:
   ConnectionManager(const ConnectionManager&);
   void operator = (const ConnectionManager&);
@@ -191,6 +199,10 @@ private:
   slot_filter_type    m_slot_filter;
   slot_resolver_type  m_slot_resolver;
   slot_throttle_type  m_slot_address_throttle;
+
+  bool                m_block_ipv4;
+  bool                m_block_ipv6;
+  bool                m_prefer_ipv6;
 };
 
 }
